#[repr(C)]pub struct xConnClientPrefix {
pub byteOrder: CARD8,
pub pad: BYTE,
pub majorVersion: CARD16,
pub minorVersion: CARD16,
pub nbytesAuthProto: CARD16,
pub nbytesAuthString: CARD16,
pub pad2: CARD16,
}Expand description
Connection setup structures. See Chapter 8: Connection Setup of the X Window System Protocol specification for details.
Fields
byteOrder: CARD8pad: BYTEmajorVersion: CARD16minorVersion: CARD16nbytesAuthProto: CARD16nbytesAuthString: CARD16pad2: CARD16Trait Implementations
Sourceimpl Clone for xConnClientPrefix
impl Clone for xConnClientPrefix
Sourcefn clone(&self) -> xConnClientPrefix
fn clone(&self) -> xConnClientPrefix
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for xConnClientPrefix
impl Debug for xConnClientPrefix
Sourceimpl Parcel for xConnClientPrefix
impl Parcel for xConnClientPrefix
Sourcefn read_field(
__io_reader: &mut dyn Read,
__settings: &Settings,
_: &mut Hints,
) -> Result<Self>
fn read_field( __io_reader: &mut dyn Read, __settings: &Settings, _: &mut Hints, ) -> Result<Self>
Reads a value from a stream. Read more
Sourcefn write_field(
&self,
__io_writer: &mut dyn Write,
__settings: &Settings,
_: &mut Hints,
) -> Result<()>
fn write_field( &self, __io_writer: &mut dyn Write, __settings: &Settings, _: &mut Hints, ) -> Result<()>
Writes a value to a stream.
Sourcefn read(read: &mut dyn Read, settings: &Settings) -> Result<Self, Error>
fn read(read: &mut dyn Read, settings: &Settings) -> Result<Self, Error>
Reads a new item with a fresh set of hints. Read more
Sourcefn write(&self, write: &mut dyn Write, settings: &Settings) -> Result<(), Error>
fn write(&self, write: &mut dyn Write, settings: &Settings) -> Result<(), Error>
Writes a value to a stream.
Sourcefn into_stream(self, settings: &Settings) -> Result<Cursor<Vec<u8>>, Error>
fn into_stream(self, settings: &Settings) -> Result<Cursor<Vec<u8>>, Error>
Convers the value into a byte stream that implements
std::io::Read.Sourcefn from_raw_bytes(bytes: &[u8], settings: &Settings) -> Result<Self, Error>
fn from_raw_bytes(bytes: &[u8], settings: &Settings) -> Result<Self, Error>
Parses a new value from its raw byte representation. Read more
Sourcefn field_from_raw_bytes(
bytes: &[u8],
settings: &Settings,
hints: &mut Hints,
) -> Result<Self, Error>
fn field_from_raw_bytes( bytes: &[u8], settings: &Settings, hints: &mut Hints, ) -> Result<Self, Error>
Parses a new value from its raw byte representation. Read more
Sourcefn raw_bytes(&self, settings: &Settings) -> Result<Vec<u8>, Error>
fn raw_bytes(&self, settings: &Settings) -> Result<Vec<u8>, Error>
Gets the raw byte representation of the value.
Sourceimpl PartialEq for xConnClientPrefix
impl PartialEq for xConnClientPrefix
impl Copy for xConnClientPrefix
impl Eq for xConnClientPrefix
impl StructuralPartialEq for xConnClientPrefix