#[repr(C)]pub struct xGrabPointerReply {
pub type_: BYTE,
pub status: BYTE,
pub sequenceNumber: CARD16,
pub length: CARD32,
pub pad1: CARD32,
pub pad2: CARD32,
pub pad3: CARD32,
pub pad4: CARD32,
pub pad5: CARD32,
pub pad6: CARD32,
}Fields
type_: BYTEstatus: BYTEsequenceNumber: CARD16length: CARD32pad1: CARD32pad2: CARD32pad3: CARD32pad4: CARD32pad5: CARD32pad6: CARD32Trait Implementations
Sourceimpl Clone for xGrabPointerReply
impl Clone for xGrabPointerReply
Sourcefn clone(&self) -> xGrabPointerReply
fn clone(&self) -> xGrabPointerReply
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for xGrabPointerReply
impl Debug for xGrabPointerReply
Sourceimpl Parcel for xGrabPointerReply
impl Parcel for xGrabPointerReply
Sourcefn read_field(
__io_reader: &mut dyn Read,
__settings: &Settings,
_: &mut Hints,
) -> Result<Self>
fn read_field( __io_reader: &mut dyn Read, __settings: &Settings, _: &mut Hints, ) -> Result<Self>
Reads a value from a stream. Read more
Sourcefn write_field(
&self,
__io_writer: &mut dyn Write,
__settings: &Settings,
_: &mut Hints,
) -> Result<()>
fn write_field( &self, __io_writer: &mut dyn Write, __settings: &Settings, _: &mut Hints, ) -> Result<()>
Writes a value to a stream.
Sourcefn read(read: &mut dyn Read, settings: &Settings) -> Result<Self, Error>
fn read(read: &mut dyn Read, settings: &Settings) -> Result<Self, Error>
Reads a new item with a fresh set of hints. Read more
Sourcefn write(&self, write: &mut dyn Write, settings: &Settings) -> Result<(), Error>
fn write(&self, write: &mut dyn Write, settings: &Settings) -> Result<(), Error>
Writes a value to a stream.
Sourcefn into_stream(self, settings: &Settings) -> Result<Cursor<Vec<u8>>, Error>
fn into_stream(self, settings: &Settings) -> Result<Cursor<Vec<u8>>, Error>
Convers the value into a byte stream that implements
std::io::Read.Sourcefn from_raw_bytes(bytes: &[u8], settings: &Settings) -> Result<Self, Error>
fn from_raw_bytes(bytes: &[u8], settings: &Settings) -> Result<Self, Error>
Parses a new value from its raw byte representation. Read more
Sourcefn field_from_raw_bytes(
bytes: &[u8],
settings: &Settings,
hints: &mut Hints,
) -> Result<Self, Error>
fn field_from_raw_bytes( bytes: &[u8], settings: &Settings, hints: &mut Hints, ) -> Result<Self, Error>
Parses a new value from its raw byte representation. Read more
Sourcefn raw_bytes(&self, settings: &Settings) -> Result<Vec<u8>, Error>
fn raw_bytes(&self, settings: &Settings) -> Result<Vec<u8>, Error>
Gets the raw byte representation of the value.
Sourceimpl PartialEq for xGrabPointerReply
impl PartialEq for xGrabPointerReply
impl Copy for xGrabPointerReply
impl Eq for xGrabPointerReply
impl StructuralPartialEq for xGrabPointerReply