#[repr(C)]pub struct xReply {Show 39 fields
pub generic: __BindgenUnionField<xGenericReply>,
pub geom: __BindgenUnionField<xGetGeometryReply>,
pub tree: __BindgenUnionField<xQueryTreeReply>,
pub atom: __BindgenUnionField<xInternAtomReply>,
pub atomName: __BindgenUnionField<xGetAtomNameReply>,
pub property: __BindgenUnionField<xGetPropertyReply>,
pub listProperties: __BindgenUnionField<xListPropertiesReply>,
pub selection: __BindgenUnionField<xGetSelectionOwnerReply>,
pub grabPointer: __BindgenUnionField<xGrabPointerReply>,
pub grabKeyboard: __BindgenUnionField<xGrabKeyboardReply>,
pub pointer: __BindgenUnionField<xQueryPointerReply>,
pub motionEvents: __BindgenUnionField<xGetMotionEventsReply>,
pub coords: __BindgenUnionField<xTranslateCoordsReply>,
pub inputFocus: __BindgenUnionField<xGetInputFocusReply>,
pub textExtents: __BindgenUnionField<xQueryTextExtentsReply>,
pub fonts: __BindgenUnionField<xListFontsReply>,
pub fontPath: __BindgenUnionField<xGetFontPathReply>,
pub image: __BindgenUnionField<xGetImageReply>,
pub colormaps: __BindgenUnionField<xListInstalledColormapsReply>,
pub allocColor: __BindgenUnionField<xAllocColorReply>,
pub allocNamedColor: __BindgenUnionField<xAllocNamedColorReply>,
pub colorCells: __BindgenUnionField<xAllocColorCellsReply>,
pub colorPlanes: __BindgenUnionField<xAllocColorPlanesReply>,
pub colors: __BindgenUnionField<xQueryColorsReply>,
pub lookupColor: __BindgenUnionField<xLookupColorReply>,
pub bestSize: __BindgenUnionField<xQueryBestSizeReply>,
pub extension: __BindgenUnionField<xQueryExtensionReply>,
pub extensions: __BindgenUnionField<xListExtensionsReply>,
pub setModifierMapping: __BindgenUnionField<xSetModifierMappingReply>,
pub getModifierMapping: __BindgenUnionField<xGetModifierMappingReply>,
pub setPointerMapping: __BindgenUnionField<xSetPointerMappingReply>,
pub getKeyboardMapping: __BindgenUnionField<xGetKeyboardMappingReply>,
pub getPointerMapping: __BindgenUnionField<xGetPointerMappingReply>,
pub pointerControl: __BindgenUnionField<xGetPointerControlReply>,
pub screenSaver: __BindgenUnionField<xGetScreenSaverReply>,
pub hosts: __BindgenUnionField<xListHostsReply>,
pub error: __BindgenUnionField<xError>,
pub event: __BindgenUnionField<xEvent>,
pub bindgen_union_field: [u32; 8],
}Fields
generic: __BindgenUnionField<xGenericReply>geom: __BindgenUnionField<xGetGeometryReply>tree: __BindgenUnionField<xQueryTreeReply>atom: __BindgenUnionField<xInternAtomReply>atomName: __BindgenUnionField<xGetAtomNameReply>property: __BindgenUnionField<xGetPropertyReply>listProperties: __BindgenUnionField<xListPropertiesReply>selection: __BindgenUnionField<xGetSelectionOwnerReply>grabPointer: __BindgenUnionField<xGrabPointerReply>grabKeyboard: __BindgenUnionField<xGrabKeyboardReply>pointer: __BindgenUnionField<xQueryPointerReply>motionEvents: __BindgenUnionField<xGetMotionEventsReply>coords: __BindgenUnionField<xTranslateCoordsReply>inputFocus: __BindgenUnionField<xGetInputFocusReply>textExtents: __BindgenUnionField<xQueryTextExtentsReply>fonts: __BindgenUnionField<xListFontsReply>fontPath: __BindgenUnionField<xGetFontPathReply>image: __BindgenUnionField<xGetImageReply>colormaps: __BindgenUnionField<xListInstalledColormapsReply>allocColor: __BindgenUnionField<xAllocColorReply>allocNamedColor: __BindgenUnionField<xAllocNamedColorReply>colorCells: __BindgenUnionField<xAllocColorCellsReply>colorPlanes: __BindgenUnionField<xAllocColorPlanesReply>colors: __BindgenUnionField<xQueryColorsReply>lookupColor: __BindgenUnionField<xLookupColorReply>bestSize: __BindgenUnionField<xQueryBestSizeReply>extension: __BindgenUnionField<xQueryExtensionReply>extensions: __BindgenUnionField<xListExtensionsReply>setModifierMapping: __BindgenUnionField<xSetModifierMappingReply>getModifierMapping: __BindgenUnionField<xGetModifierMappingReply>setPointerMapping: __BindgenUnionField<xSetPointerMappingReply>getKeyboardMapping: __BindgenUnionField<xGetKeyboardMappingReply>getPointerMapping: __BindgenUnionField<xGetPointerMappingReply>pointerControl: __BindgenUnionField<xGetPointerControlReply>screenSaver: __BindgenUnionField<xGetScreenSaverReply>hosts: __BindgenUnionField<xListHostsReply>error: __BindgenUnionField<xError>event: __BindgenUnionField<xEvent>bindgen_union_field: [u32; 8]Trait Implementations
Sourceimpl Parcel for xReply
impl Parcel for xReply
Sourcefn read_field(
__io_reader: &mut dyn Read,
__settings: &Settings,
_: &mut Hints,
) -> Result<Self>
fn read_field( __io_reader: &mut dyn Read, __settings: &Settings, _: &mut Hints, ) -> Result<Self>
Reads a value from a stream. Read more
Sourcefn write_field(
&self,
__io_writer: &mut dyn Write,
__settings: &Settings,
_: &mut Hints,
) -> Result<()>
fn write_field( &self, __io_writer: &mut dyn Write, __settings: &Settings, _: &mut Hints, ) -> Result<()>
Writes a value to a stream.
Sourcefn read(read: &mut dyn Read, settings: &Settings) -> Result<Self, Error>
fn read(read: &mut dyn Read, settings: &Settings) -> Result<Self, Error>
Reads a new item with a fresh set of hints. Read more
Sourcefn write(&self, write: &mut dyn Write, settings: &Settings) -> Result<(), Error>
fn write(&self, write: &mut dyn Write, settings: &Settings) -> Result<(), Error>
Writes a value to a stream.
Sourcefn into_stream(self, settings: &Settings) -> Result<Cursor<Vec<u8>>, Error>
fn into_stream(self, settings: &Settings) -> Result<Cursor<Vec<u8>>, Error>
Convers the value into a byte stream that implements
std::io::Read.Sourcefn from_raw_bytes(bytes: &[u8], settings: &Settings) -> Result<Self, Error>
fn from_raw_bytes(bytes: &[u8], settings: &Settings) -> Result<Self, Error>
Parses a new value from its raw byte representation. Read more
Sourcefn field_from_raw_bytes(
bytes: &[u8],
settings: &Settings,
hints: &mut Hints,
) -> Result<Self, Error>
fn field_from_raw_bytes( bytes: &[u8], settings: &Settings, hints: &mut Hints, ) -> Result<Self, Error>
Parses a new value from its raw byte representation. Read more
Sourcefn raw_bytes(&self, settings: &Settings) -> Result<Vec<u8>, Error>
fn raw_bytes(&self, settings: &Settings) -> Result<Vec<u8>, Error>
Gets the raw byte representation of the value.
impl Copy for xReply
impl Eq for xReply
impl StructuralPartialEq for xReply